@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: An algorithmic MIDI drummer
 
-our $VERSION = '0.0812';
+our $VERSION = '0.0813';
 
 use strict;
 use warnings;
@@ -563,7 +563,7 @@ MIDI::Simple::Drummer - An algorithmic MIDI drummer
 
 =head1 VERSION
 
-version 0.0812
+version 0.0813
 
 =head1 SYNOPSIS
 
@@ -637,7 +637,7 @@ version 0.0812
 
 =head1 DESCRIPTION
 
-* While still viable, this module has most been superseded by
+* While still viable, this module has mostly been superseded by
 L<MIDI::Drummer::Tiny>.
 
 This is a "robotic" drummer that provides algorithmic methods to make beats,
